[git] GnuPG - branch, master, updated. gnupg-2.2.4-114-g26c900a

by Werner Koch cvs at cvs.gnupg.org
Thu Feb 1 12:11:49 CET 2018


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "The GNU Privacy Guard".

The branch, master has been updated
       via  26c900a8f09df5a15cc9dfce11b98a1caa2dd682 (commit)
       via  303310d05e708dd58dcf7b7d8e8634cd5085bc7e (commit)
      from  660eafa3a9f68e116e9b0597edc317d8ff90f9b2 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 26c900a8f09df5a15cc9dfce11b98a1caa2dd682
Author: Werner Koch <wk at gnupg.org>
Date:   Thu Feb 1 12:02:13 2018 +0100

    Add a new OpenPGP card vendor.
    
    --

diff --git a/g10/card-util.c b/g10/card-util.c
index 854b94f..4c1ab03 100644
--- a/g10/card-util.c
+++ b/g10/card-util.c
@@ -216,6 +216,7 @@ get_manufacturer (unsigned int no)
 
     case 0x1337: return "Warsaw Hackerspace";
     case 0x2342: return "warpzone"; /* hackerspace Muenster.  */
+    case 0xBD0E: return "Paranoidlabs";
     case 0xF517: return "FSIJ";
 
       /* 0x0000 and 0xFFFF are defined as test cards per spec,

commit 303310d05e708dd58dcf7b7d8e8634cd5085bc7e
Author: Werner Koch <wk at gnupg.org>
Date:   Sun Jan 28 18:59:18 2018 +0100

    gpg: Rename a misnomed arg in open_outfile.
    
    * g10/openfile.c (open_outfile): Rename inp_fd to out_fd.
    
    Signed-off-by: Werner Koch <wk at gnupg.org>

diff --git a/g10/main.h b/g10/main.h
index 2f7c159..de8639e 100644
--- a/g10/main.h
+++ b/g10/main.h
@@ -341,7 +341,7 @@ gpg_error_t generate_card_subkeypair (ctrl_t ctrl, kbnode_t pub_keyblock,
 int overwrite_filep( const char *fname );
 char *make_outfile_name( const char *iname );
 char *ask_outfile_name( const char *name, size_t namelen );
-int open_outfile (int inp_fd, const char *iname, int mode,
+int open_outfile (int out_fd, const char *iname, int mode,
                   int restrictedperm, iobuf_t *a);
 char *get_matching_datafile (const char *sigfilename);
 iobuf_t open_sigfile (const char *sigfilename, progress_filter_context_t *pfx);
diff --git a/g10/openfile.c b/g10/openfile.c
index 78f4dbb..f4730da 100644
--- a/g10/openfile.c
+++ b/g10/openfile.c
@@ -171,32 +171,34 @@ ask_outfile_name( const char *name, size_t namelen )
  *	2 = use ".sig"
  *      3 = use ".rev"
  *
  * If INP_FD is not -1 the function simply creates an IOBUF for that
  * file descriptor and ignore INAME and MODE.  Note that INP_FD won't
  * be closed if the returned IOBUF is closed.  With RESTRICTEDPERM a
  * file will be created with mode 700 if possible.
  */
 int
-open_outfile (int inp_fd, const char *iname, int mode, int restrictedperm,
+open_outfile (int out_fd, const char *iname, int mode, int restrictedperm,
               iobuf_t *a)
 {
   int rc = 0;
 
   *a = NULL;
-  if (inp_fd != -1)
+  if (out_fd != -1)
     {
       char xname[64];
 
-      *a = iobuf_fdopen_nc (inp_fd, "wb");
+      *a = iobuf_fdopen_nc (out_fd, "wb");
       if (!*a)
         {
           rc = gpg_error_from_syserror ();
-          snprintf (xname, sizeof xname, "[fd %d]", inp_fd);
+          snprintf (xname, sizeof xname, "[fd %d]", out_fd);
           log_error (_("can't open '%s': %s\n"), xname, gpg_strerror (rc));
         }
       else if (opt.verbose)
         {
-          snprintf (xname, sizeof xname, "[fd %d]", inp_fd);
+          snprintf (xname, sizeof xname, "[fd %d]", out_fd);
           log_info (_("writing to '%s'\n"), xname);
         }
     }

-----------------------------------------------------------------------

Summary of changes:
 g10/card-util.c |  1 +
@@ -171,32 +171,34 @@ ask_outfile_name( const char *name, size_t namelen )
  *      3 = use ".rev"
  *
- * If INP_FD is not -1 the function simply creates an IOBUF for that
- * file descriptor and ignore INAME and MODE.  Note that INP_FD won't
- * be closed if the returned IOBUF is closed.  With RESTRICTEDPERM a
- * file will be created with mode 700 if possible.
- */
+ * With RESTRICTEDPERM a file will be created with mode 700 if
+ * possible.
+ *
+ * If OUT_FD is not -1 the function simply creates an IOBUF for that
+ * file descriptor and ignores INAME and MODE.  Note that OUT_FD won't
+ * be closed if the returned IOBUF is closed.  This is used for gpg's
+ * --server mode.  */
 int
 g10/main.h      |  2 +-
 g10/openfile.c  | 22 ++++++++++++----------
 3 files changed, 14 insertions(+), 11 deletions(-)


hooks/post-receive
-- 
The GNU Privacy Guard
http://git.gnupg.org




More information about the Gnupg-commits mailing list